@@ -2,12 +2,12 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from party import *
-from sale import *
+from . import party
+from . import sale
 
 
 def register():
     Pool.register(
-        Party,
-        Sale,
+        party.Party,
+        sale.Sale,
         module='sale_credit_limit', type_='model')
